Client manual
=============

Authentication
--------------

Is this your first visit? Then you must first start an RA. You already started
with an e-mail address and a password. After that you give the RA a title. Next
you can start the RA.

Stopping and starting an existing RA
------------------------------------

Once you have started an RA, you will be able to stop before the end.  Log out:
the data will be stored. If you forgot to log out and just ended the RA, the
data will be stored too. For security reasons it is better to officially log
out. Of course your must remember your e-mail address, password and the title
that you have given the RA. You can start the stored RA again at a later date:
select the title of the RA. You can save more than one RA, provided you have
given them different titles names.

Sessions
--------

Just start. The programme will point you in the right direction. 

You will find buttons: 

* *Next*: this takes you to the next screen.
* *Previous*: this takes you to the previous screen.
* *Help*: this takes you to the online manual.
* *Log out* : use this button if you want to stop before the end. The data that
  you have entered will be saved. Keep in mind: remember the title of the RA.
* *Status*. The button will show you your progress handling the RA tool. Why view
  the status?  Drawing up an RA is not something you can do in one session.
  Therefore, it can be useful to see where you ended the last session. This can
  be done on these pages.

You will also see:

* Buttons at the top: these list the steps in the RA, such as Identification,
  Evaluation and Action Plan. 
* On the left side: the question overview, with modules and questions. You can
  select these by clicking on them
* In the modules you will find a progress indicator (how far am I?) and a
  status indicator (what has been organised properly: green, what could be
  improved: red, what will I answer at a later stage: orange).

Preparation
------------

Why do you need a company profile?

Before starting with the RA, you must first determine your company profile.
This is particularly important if your company consists of more than one
business unit. For example, if your store has more than one branch, then you
must answer the RA questions separately for each branch. By indicating the
composition of your company here, this means that it will be automatically
included in the Inventory. It is useful to give company sections a clear name.

How to determine a company profile?

* On the page ‘Determine your company profile’ you indicate the type of
  business units that occur in your company.
* Does your company consist of several stores, branches or similar? Enter each
  store, branch or similar separately and give them a name.

Have you forgotten to determine your company profile? Start again with the RA
and give the RA a different name. Remember that what you have already filled in
will have to be filled in again.

Identification
--------------

Evaluation
----------

Why evaluate?
~~~~~~~~~~~~~
Once you have answered all the questions, you can evaluate. That means that you
will receive a summary of all the bottlenecks in your company. Please bear in
mind that: one bottleneck may be more severe than another. Therefore, the
magnitude of the risk is determined here.

High, medium and low
~~~~~~~~~~~~~~~~~~~~

The step *Evaluate* is performed by answering three questions for each
bottleneck. Your three answers will be used in a calculation, based on which
the programme determines whether the risk is high, medium or low. In the next
step, ‘Action Plan’, you will find more information about the outcome of this
calculation.

What are bottlenecks?
~~~~~~~~~~~~~~~~~~~~~

Bottlenecks are questions in the phase Identify that were answered with a ‘No’.
These questions are flagged again here. However, it is possible that you
answered ‘No’ to certain questions but these questions do not pop up in the
phase "Evaluation". There are two possible reasons for this.

* Either: a certain bottleneck is known to cause high risks in your sector (for
  example, in the case of occupational diseases). In that case the bottleneck
  will only be listed in the Action Plan, with the warning ‘Risk: high’.
* Or: this is a bottleneck for which the risk cannot be determined based on
  these three questions (for example for the bottleneck: absence of policy). In
  that case the bottleneck will also only be listed in the Action Plan, with
  the warning ‘Risk: not defined’.

You will assign priorities to these bottlenecks yourself in the Action Plan.

How can you check that all bottlenecks have been evaluated?
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

They will appear in the Action Plan with the warning ‘Risk: not defined’.

What if there are no bottlenecks?
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

That is possible. This is good as it means there are no health or safety risks
in your company. You can simply skip the steps ‘Evaluation’ and ‘Action Plan’.

How to evaluate?
~~~~~~~~~~~~~~~~

The step Evaluation is performed by answering the following three questions for each bottleneck:

* How often are people exposed to this risk? You can select: ‘Never’, ‘Almost
  never’, ‘Regularly’ or ‘Constantly’.
* What is the chance of this risk occurring? You can select: ‘Small’, ‘Medium’
  or ‘Very big’.
* Which is the severity of the damage?  You can select: ‘Weak severity’,
  ‘Significant severity’ or ‘High (very high) severity’.

An example
~~~~~~~~~~

There are hazardous substances in a storeroom. The employees enter this room
briefly several times per week. The storage has been fitted with an extractor.
The chance of hazardous substances being released (for example by leakage or
vaporisation) is estimated to be medium (there are various substances in
different types of packaging). The exposure is defined as regular (the
employees enter the room several times per week). And the severity is
significant (the substances are irritating, but not toxic).

Suggestion!
~~~~~~~~~~~

Use your common sense when filling in the forms. Do not pay any attention to
all sorts of other possible and conceivable effects.

Action Plan
-----------

Why set up an Action Plan?
~~~~~~~~~~~~~~~~~~~~~~~~~~

You have defined the bottlenecks in your company. You have determined the level
of risk for each bottleneck. The question that remains is: what can you do
about it? In other words: what measures can you implement to remove these
bottlenecks?

First priority...
~~~~~~~~~~~~~~~~~

The programme runs through the bottlenecks one at a time. First you must set
the priority: how important do you think it is that this bottleneck is tackled
quickly? The programme automatically assigns a high priority to a bottleneck
with a high risk et cetera. You can modify the priorities yourself.

...then the measures
~~~~~~~~~~~~~~~~~~~~

Now there are two options for each bottleneck: you select one of the standard
measures suggested by the programme. These are measures that are normally used
in your sector. Some sectors list several standard measures, others do not. Or
you decide on the best measures by yourself. 

How to set the priority?
~~~~~~~~~~~~~~~~~~~~~~~~

You select a high, medium or low priority for the bottleneck. You leave the
priority as set by the programme, or you modify it.

How to select measures?
~~~~~~~~~~~~~~~~~~~~~~~

Sometimes one or more standard measures are suggested. You can select one or
more of these measures, or you can modify the text of the measure yourself! Or
you can add your own measures.  If you have added at the phase Identify your
own notes, you can see them at the page Action Plan.

Fill in 

* Prevention plan: the tasks that have to be carried out.
* Requirements: the knowledge and experience needed to carry out the tasks.
* Responsibility: the person in charge of the implementation.
* Budget: the costs that will have to be incurred.
* The start date and end date.

Report
~~~~~~

Why report and print? You have now completed your RA. You can print copies for
yourself and your employees. Please ensure that you always have a printed
version of your RA available. This is useful when a Labour Inspectorate team
visits. They will ask to see this document. (This can vary in each country).

How to modify the RA?
~~~~~~~~~~~~~~~~~~~~~

Once you have saved the report, you can modify it using your word processor
(for example, Microsoft Word or Windows WordPad). Or restart the digital RA,
and modify.

.. note:: The changes with your word processor will not be automatically
          adopted in the programme used to complete the RA.

Why add additional information to the report?
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

If you have saved the report you can add additional information like the name
of your company, person(s) who carried out the examination, date of the RA.
This additional information can be useful for supervisory authorities.

Final words
~~~~~~~~~~~~

Keep it safe! Store your RA safely. You have put a lot of effort into it. You
can close the RA by clicking on the button ‘Log out RA’ on the top right. This
will automatically save the RA and close it. Your data have been stored. Once
the save has been completed you will return to the screen ‘Select RA’. Here you
can open another (existing) or new RA if necessary. However, you will probably
just want to close the programme.

What will happen next?
~~~~~~~~~~~~~~~~~~~~~~

You will start to implement your Action Plan. Conduct an RA regularly.
Especially if there are any changes in your company. For example, when you buy
a new machine, before and after reconstruction or moving. A rule of thumb is
once every four to five years. You do not have to start the RA from scratch
every time.

